# Security Policy

## Supported Versions

Always use the latest major version of OZI.build

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev
